==> haskell-network-info-0.2.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-info.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-info
version:              0.2.1
visibility:           public
id:                   network-info-0.2.1-KKhPoqXltWn3GAhxqG8FXO
key:                  network-info-0.2.1-KKhPoqXltWn3GAhxqG8FXO
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             http://github.com/jacobstanley/network-info
synopsis:             Access the local computer'\''s basic network configuration
description:
    This library provides simple read-only access to the
    local computer'\''s networking configuration. It is
    currently capable of getting a list of all the network
    interfaces and their respective IPv4, IPv6 and MAC
    addresses.

    network-info has been tested and is known to work on
    Ubuntu, FreeBSD, NetBSD, Mac OS and Windows.

category:             Network
abi:                  ac10e63b2bed6716dbbd57137919c707
exposed:              True
exposed-modules:      Network.Info
import-dirs:          /usr/lib/ghc-9.2.8/site-local/network-info-0.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/network-info-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-info
hs-libraries:         HSnetwork-info-0.2.1-KKhPoqXltWn3GAhxqG8FXO
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-network-info/html/network-info.haddock

haddock-html:         /usr/share/doc/haskell-network-info/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-info-0.2.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-info.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-info
version:              0.2.1
visibility:           public
id:                   network-info-0.2.1-DF9aJuNW45HC0966sT94Vy
key:                  network-info-0.2.1-DF9aJuNW45HC0966sT94Vy
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             http://github.com/jacobstanley/network-info
synopsis:             Access the local computer'\''s basic network configuration
description:
    This library provides simple read-only access to the
    local computer'\''s networking configuration. It is
    currently capable of getting a list of all the network
    interfaces and their respective IPv4, IPv6 and MAC
    addresses.

    network-info has been tested and is known to work on
    Ubuntu, FreeBSD, NetBSD, Mac OS and Windows.

category:             Network
abi:                  71dbac5f28c5ea0877667324aa3f4552
exposed:              True
exposed-modules:      Network.Info
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-info-0.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-info-0.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-info-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-info
hs-libraries:         HSnetwork-info-0.2.1-DF9aJuNW45HC0966sT94Vy
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-network-info/html/network-info.haddock

haddock-html:         /usr/share/doc/haskell-network-info/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
